@@ -6,4 +6,7 @@
 ##parameters=
 ##                                                                                                                                   
 
-return 'mailto:'
+if 'Email message' in map(lambda x: x.content_meta_type, context.allowedContentTypes()):
+    return context.absolute_url() + '/create_email?to='
+else:
+    return 'mailto:'
